==> verticalpodautoscaler-model-v1-6.6.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RecommendedPodResourcesFluentImpl<A extends RecommendedPodResourcesFluent<A>> extends BaseFluent<A> implements RecommendedPodResourcesFluent<A>{
  public RecommendedPodResourcesFluentImpl() {
  }
  public RecommendedPodResourcesFluentImpl(RecommendedPodResources instance) {
    this.withContainerRecommendations(instance.getContainerRecommendations()); 
  }
  private ArrayList<RecommendedContainerResourcesBuilder> containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();
  public A addToContainerRecommendations(Integer index,RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(index >= 0 ? index : _visitables.get("containerRecommendations").size(), builder);this.containerRecommendations.add(index >= 0 ? index : containerRecommendations.size(), builder); return (A)this;
  }
  public A setToContainerRecommendations(Integer index,RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);
    if (index < 0 || index >= _visitables.get("containerRecommendations").size()) { _visitables.get("containerRecommendations").add(builder); } else { _visitables.get("containerRecommendations").set(index, builder);}
    if (index < 0 || index >= containerRecommendations.size()) { containerRecommendations.add(builder); } else { containerRecommendations.set(index, builder);}
     return (A)this;
  }
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A addAllToContainerRecommendations(Collection<RecommendedContainerResources> items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeAllFromContainerRecommendations(Collection<RecommendedContainerResources> items) {
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromContainerRecommendations(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    if (containerRecommendations == null) return (A) this;
    final Iterator<RecommendedContainerResourcesBuilder> each = containerRecommendations.iterator();
    final List visitables = _visitables.get("containerRecommendations");
    while (each.hasNext()) {
      RecommendedContainerResourcesBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RecommendedContainerResources> getContainerRecommendations() {
    return containerRecommendations != null ? build(containerRecommendations) : null;
  }
  public List<RecommendedContainerResources> buildContainerRecommendations() {
    return containerRecommendations != null ? build(containerRecommendations) : null;
  }
  public RecommendedContainerResources buildContainerRecommendation(Integer index) {
    return this.containerRecommendations.get(index).build();
  }
  public RecommendedContainerResources buildFirstContainerRecommendation() {
    return this.containerRecommendations.get(0).build();
  }
  public RecommendedContainerResources buildLastContainerRecommendation() {
    return this.containerRecommendations.get(containerRecommendations.size() - 1).build();
  }
  public RecommendedContainerResources buildMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    for (RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    for (RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerRecommendations(List<RecommendedContainerResources> containerRecommendations) {
    if (this.containerRecommendations != null) { _visitables.get("containerRecommendations").removeAll(this.containerRecommendations);}
    if (containerRecommendations != null) {this.containerRecommendations = new ArrayList(); for (RecommendedContainerResources item : containerRecommendations){this.addToContainerRecommendations(item);}} else { this.containerRecommendations = null;} return (A) this;
  }
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations) {
    if (this.containerRecommendations != null) {this.containerRecommendations.clear();}
    if (containerRecommendations != null) {for (RecommendedContainerResources item :containerRecommendations){ this.addToContainerRecommendations(item);}} return (A) this;
  }
  public Boolean hasContainerRecommendations() {
    return containerRecommendations != null && !containerRecommendations.isEmpty();
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendation() {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl();
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(RecommendedContainerResources item) {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(-1, item);
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(Integer index,RecommendedContainerResources item) {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(index, item);
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editContainerRecommendation(Integer index) {
    if (containerRecommendations.size() <= index) throw new RuntimeException("Can't edit containerRecommendations. Index exceeds size.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editFirstContainerRecommendation() {
    if (containerRecommendations.size() == 0) throw new RuntimeException("Can't edit first containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(0, buildContainerRecommendation(0));
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editLastContainerRecommendation() {
    int index = containerRecommendations.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    int index = -1;
    for (int i=0;i<containerRecommendations.size();i++) { 
    if (predicate.test(containerRecommendations.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching containerRecommendations. No match found.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecommendedPodResourcesFluentImpl that = (RecommendedPodResourcesFluentImpl) o;
    if (containerRecommendations != null ? !containerRecommendations.equals(that.containerRecommendations) :that.containerRecommendations != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRecommendations,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerRecommendations != null && !containerRecommendations.isEmpty()) { sb.append("containerRecommendations:"); sb.append(containerRecommendations); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerRecommendationsNestedImpl<N> extends RecommendedContainerResourcesFluentImpl<RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>> implements RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>,Nested<N>{
    ContainerRecommendationsNestedImpl(Integer index,RecommendedContainerResources item) {
      this.index = index;
      this.builder = new RecommendedContainerResourcesBuilder(this, item);
    }
    ContainerRecommendationsNestedImpl() {
      this.index = -1;
      this.builder = new RecommendedContainerResourcesBuilder(this);
    }
    RecommendedContainerResourcesBuilder builder;
    Integer index;
    public N and() {
      return (N) RecommendedPodResourcesFluentImpl.this.setToContainerRecommendations(index,builder.build());
    }
    public N endContainerRecommendation() {
      return and();
    }
    
  }
  
}

==> verticalpodautoscaler-model-v1-6.7.1-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RecommendedPodResourcesFluentImpl<A extends RecommendedPodResourcesFluent<A>> extends BaseFluent<A> implements RecommendedPodResourcesFluent<A>{
  public RecommendedPodResourcesFluentImpl() {
  }
  public RecommendedPodResourcesFluentImpl(RecommendedPodResources instance) {
    if (instance != null) {
      this.withContainerRecommendations(instance.getContainerRecommendations());
    }
  }
  private ArrayList<RecommendedContainerResourcesBuilder> containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();
  public A addToContainerRecommendations(int index,RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);
    if (index < 0 || index >= containerRecommendations.size()) { _visitables.get("containerRecommendations").add(builder); containerRecommendations.add(builder); } else { _visitables.get("containerRecommendations").add(index, builder); containerRecommendations.add(index, builder);}
    return (A)this;
  }
  public A setToContainerRecommendations(int index,RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);
    if (index < 0 || index >= containerRecommendations.size()) { _visitables.get("containerRecommendations").add(builder); containerRecommendations.add(builder); } else { _visitables.get("containerRecommendations").set(index, builder); containerRecommendations.set(index, builder);}
    return (A)this;
  }
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A addAllToContainerRecommendations(Collection<RecommendedContainerResources> items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new ArrayList<RecommendedContainerResourcesBuilder>();}
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeAllFromContainerRecommendations(Collection<RecommendedContainerResources> items) {
    for (RecommendedContainerResources item : items) {RecommendedContainerResourcesBuilder builder = new RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromContainerRecommendations(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    if (containerRecommendations == null) return (A) this;
    final Iterator<RecommendedContainerResourcesBuilder> each = containerRecommendations.iterator();
    final List visitables = _visitables.get("containerRecommendations");
    while (each.hasNext()) {
      RecommendedContainerResourcesBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RecommendedContainerResources> getContainerRecommendations() {
    return containerRecommendations != null ? build(containerRecommendations) : null;
  }
  public List<RecommendedContainerResources> buildContainerRecommendations() {
    return containerRecommendations != null ? build(containerRecommendations) : null;
  }
  public RecommendedContainerResources buildContainerRecommendation(int index) {
    return this.containerRecommendations.get(index).build();
  }
  public RecommendedContainerResources buildFirstContainerRecommendation() {
    return this.containerRecommendations.get(0).build();
  }
  public RecommendedContainerResources buildLastContainerRecommendation() {
    return this.containerRecommendations.get(containerRecommendations.size() - 1).build();
  }
  public RecommendedContainerResources buildMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    for (RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    for (RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerRecommendations(List<RecommendedContainerResources> containerRecommendations) {
    if (this.containerRecommendations != null) { _visitables.get("containerRecommendations").clear();}
    if (containerRecommendations != null) {this.containerRecommendations = new ArrayList(); for (RecommendedContainerResources item : containerRecommendations){this.addToContainerRecommendations(item);}} else { this.containerRecommendations = null;} return (A) this;
  }
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations) {
    if (this.containerRecommendations != null) {this.containerRecommendations.clear(); _visitables.remove("containerRecommendations"); }
    if (containerRecommendations != null) {for (RecommendedContainerResources item :containerRecommendations){ this.addToContainerRecommendations(item);}} return (A) this;
  }
  public Boolean hasContainerRecommendations() {
    return containerRecommendations != null && !containerRecommendations.isEmpty();
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> addNewContainerRecommendation() {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl();
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(RecommendedContainerResources item) {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(-1, item);
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(int index,RecommendedContainerResources item) {
    return new RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(index, item);
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> editContainerRecommendation(int index) {
    if (containerRecommendations.size() <= index) throw new RuntimeException("Can't edit containerRecommendations. Index exceeds size.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> editFirstContainerRecommendation() {
    if (containerRecommendations.size() == 0) throw new RuntimeException("Can't edit first containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(0, buildContainerRecommendation(0));
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> editLastContainerRecommendation() {
    int index = containerRecommendations.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(Predicate<RecommendedContainerResourcesBuilder> predicate) {
    int index = -1;
    for (int i=0;i<containerRecommendations.size();i++) { 
    if (predicate.test(containerRecommendations.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching containerRecommendations. No match found.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecommendedPodResourcesFluentImpl that = (RecommendedPodResourcesFluentImpl) o;
    if (!java.util.Objects.equals(containerRecommendations, that.containerRecommendations)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRecommendations,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerRecommendations != null) { sb.append("containerRecommendations:"); sb.append(containerRecommendations); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerRecommendationsNestedImpl<N> extends RecommendedContainerResourcesFluentImpl<RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<N>> implements RecommendedPodResourcesFluentImpl.ContainerRecommendationsNested<N>,Nested<N>{
    ContainerRecommendationsNestedImpl(int index,RecommendedContainerResources item) {
      this.index = index;
      this.builder = new RecommendedContainerResourcesBuilder(this, item);
    }
    ContainerRecommendationsNestedImpl() {
      this.index = -1;
      this.builder = new RecommendedContainerResourcesBuilder(this);
    }
    RecommendedContainerResourcesBuilder builder;
    int index;
    public N and() {
      return (N) RecommendedPodResourcesFluentImpl.this.setToContainerRecommendations(index,builder.build());
    }
    public N endContainerRecommendation() {
      return and();
    }
    
  }
  
}
